From: david-sarah <david-sarah@jacaranda.org>
Date: Wed, 19 Jan 2011 04:24:01 +0000 (-0800)
Subject: Change misc/build_helpers/test-with-fake-pkg to use 'setup.py trial'. refs #1296
X-Git-Tag: allmydata-tahoe-1.8.2b1~41
X-Git-Url: https://git.rkrishnan.org/pf/content/simplejson/install.html?a=commitdiff_plain;h=5a7c99d29d85f32d55c97ba73d29c3a45bdfef51;p=tahoe-lafs%2Ftahoe-lafs.git

Change misc/build_helpers/test-with-fake-pkg to use 'setup.py trial'. refs #1296
---

diff --git a/misc/build_helpers/test-with-fake-pkg.py b/misc/build_helpers/test-with-fake-pkg.py
index d4ae7311..f3ecf880 100644
--- a/misc/build_helpers/test-with-fake-pkg.py
+++ b/misc/build_helpers/test-with-fake-pkg.py
@@ -2,7 +2,7 @@
 
 # We put a fake "pycryptopp-0.5.13" package on the PYTHONPATH so that
 # the build system thinks pycryptopp-0.5.13 is already installed. Then
 # we execute run_trial.py. If the build system is too naive/greedy
 # about finding dependencies, it will latch onto the
 # "pycryptopp-0.5.13" and then will be unable to satisfy the
 # requirement (from _auto_deps.py) for pycryptopp >= 0.5.20 (or
@@ -11,7 +11,7 @@
 # test-with-fake-pkg.py shows a failure, but with the ticket1190
 # branch, test-with-fake-pkg.py succeeds.
 
-import glob, os, subprocess, sys
+import os, subprocess, sys
 
 fakepkgdir = 'misc/build_helpers/fakepkgs'
 fakepkgname = "pycryptopp"
@@ -25,9 +25,6 @@ try:
 except OSError:
     # probably already exists
     pass
-os.chdir('src')
-trial=os.path.join(os.getcwd(), '..', 'misc', 'build_helpers', 'run_trial.py')
-os.environ['PATH']=os.getcwd()+os.pathsep+os.environ['PATH']
-eggs = [os.path.realpath(p) for p in glob.glob(os.path.join('..', '*.egg'))]
-os.environ['PYTHONPATH']=os.pathsep+pkgdirname+os.pathsep+os.pathsep.join(eggs)+os.pathsep+os.environ.get('PYTHONPATH','')
-sys.exit(subprocess.call([sys.executable, trial, testsuite], env=os.environ))
+
+os.environ['PYTHONPATH']=pkgdirname+os.pathsep+os.environ.get('PYTHONPATH','')
+sys.exit(subprocess.call([sys.executable, 'setup.py', 'trial', '-s', testsuite], env=os.environ))
@@ -2,7 +2,7 @@
 # We put a fake "pycryptopp-0.5.13" package on the PYTHONPATH so that
 # the build system thinks pycryptopp-0.5.13 is already installed. Then
-# we execute run_trial.py. If the build system is too naive/greedy
+# we execute 'setup.py trial'. If the build system is too naive/greedy
 # about finding dependencies, it will latch onto the
 # "pycryptopp-0.5.13" and then will be unable to satisfy the